@@ -48,6 +48,8 @@ parser.add_option("-a", "--authors", action="store_true", dest="authors",
                   help="also show authors of videos")
 parser.add_option("-s", "--status", action="store_true", dest="status",
                   help="show the status of the download queue")
+parser.add_option("-m", "--more", action="store_true", dest="more",
+                  help="show up to 50 more results using the last search term")
 parser.add_option("-p", "--play", action="store", dest="play",
                   help="play the video number ID as a direct stream",
                   metavar="ID", type="int")
@@ -289,8 +291,17 @@ def resume():
     sys.stdout.flush()
     os.system("/usr/bin/python /opt/ytcli/ytcli_queue.py &")
 
+def more():
+  '''show results for the last search term used'''
+  try:
+    previous_term = config.get(D, 'term')
+  except:
+    print "No previous search found. Run a search using -f first."
+    sys.exit(1)
+  find(previous_term) 
+
 def find(term):
-  '''show the results for term starting including privious resultss'''
+  '''show the results for term starting including privious results'''
   d = {}
   try:
     previous_term = config.get(D, 'term')
@@ -329,19 +340,24 @@ def find(term):
 # decide and do
 if options.find:
   find(options.find)
-if options.queue:
+elif options.more:
+  more()
+elif options.queue:
   queue(options.queue)
-if options.status:
+elif options.status:
   status()
-if options.play:
+elif options.play:
   play(options.play)
-if options.playYoutube:
+elif options.playYoutube:
   play_youtube(options.playYoutube)
-if options.reset:
+elif options.reset:
   reset(options.reset)
-if options.kill:
+elif options.kill:
   kill()
-if options.remove is not None:
+elif options.remove is not None:
   remove(options.remove)
-if options.resume:
+elif options.resume:
   resume()
+else:
+  print "Missing arguments. See ytcli -h for help on how to use ytcli"
+  sys.exit(1)
